[![Python CI](https://github.com/emcek/venvflon/actions/workflows/python-ci.yml/badge.svg?branch=master)](https://github.com/emcek/venvflon/actions/workflows/python-ci.yml)
[![image](https://img.shields.io/badge/pypi-v0.1.0-blue.svg)](https://pypi.org/project/venvflon/)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/emcek/venvflon/master.svg)](https://results.pre-commit.ci/latest/github/emcek/venvflon/master)
[![License](https://img.shields.io/badge/License-MIT-blue.svg)](./LICENSE)
[![Downloads](https://img.shields.io/github/downloads/emcek/venvflon/total?label=Downloads)](https://github.com/emcek/venvflon/releases)
[![venvflon](https://snyk.io/advisor/python/venvflon/badge.svg)](https://snyk.io/advisor/python/venvflon)
[![image](https://img.shields.io/badge/python-3.9%20%7C%203.10%20%7C%203.11%20%7C%203.12%20%7C%203.13-blue.svg)](https://github.com/emcek/venvflon)

[//]: # ([![dcspy]&#40;https://snyk.io/advisor/python/dcspy/badge.svg&#41;]&#40;https://snyk.io/advisor/python/venvflon&#41;)
[//]: # ([![Downloads]&#40;https://static.pepy.tech/badge/venvflon&#41;]&#40;https://pepy.tech/project/venvflon&#41;)

# venvflon
simple virtual environment switcher

## name
Comes from polish `wenflon` or `kaniula` (eng. `cannula`)
